@@ -1599,4 +1599,67 @@ class get_data_response(msg):
             
     def __init__(self):
         super().__init__()
-        self.data = self.msg_class()  # 消息体
\ No newline at end of file
+        self.data = self.msg_class()  # 消息体
+        
+#给传感器发送充电指令
+class charging_order(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "data":"start" //指令说明： start： 开始充电； stop： 停止充电
+    }
+    """
+    topic = "/charging/order"
+    
+
+    def __init__(self):
+        super().__init__()
+        self.data = ''  # 消息体
+
+#给传感器发送充电指令返回值
+class charging_order_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "data":true //指令说明： 指令成功
+    }
+    """
+    topic = "/charging/order_response"
+    
+
+    def __init__(self):
+        super().__init__()
+        self.data = ''  # 消息体
+
+#无线充电传感器状态
+class charging_status(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "task_id": "",
+        "data": {
+            "voltage": 22.00,  //电压
+            "current": 12.10, //电流
+            "temperature": 30.00, //充电器温度
+            "status": 0.0 , //系统状态： 0x00 表示未充电； 0x01 表示在充电段1，涓流充电； 0x02 表示在充电段2，恒流充电； 0x03 表示在充电段3，恒压充电； 0x04 表示在充电段4，预留； 0x05 表示在充电段5，预留。
+            "error": 0.0, //故障码： 0x00 表示无故障； 0x02 表示充电过流； 0x03 表示充电欠流; 0x04 表示充电前级电压过压； 0x05 表示充电前级电压欠压； 0x06 表示充电过压； 0x07 表示电池异常； 0x08 表示过温； 0x09 表示电池充满； 0x0A 表示线圈零距离。
+            "sys_code": 0.0, //系统状态： 0x00 表示系统正常待机，等待接收 上位机控制指令； 0x01 表示系统 接 收 到 不 正 确 的 上位机指令，需要重新发送指令； 0x02 表示系统接收到正确的上位机 指令，开始正常启动工作。
+            }
+    }
+    """
+    topic = "/charging/status"
+    
+    class data_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.voltage = ""  # float型
+            self.current = ""  # float型
+            self.temperature = ""  # float型
+            self.status = ""  # float型
+            self.error = "" # float型
+            self.sys_code = "" # float型
+            
+    def __init__(self):
+        super().__init__()
+        self.data = self.data_class()  # 消息体
+        self.task_id = ''  # string型
\ No newline at end of file
